FrameAddress (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class FrameAddress

    java.lang.Object
      org.openqa.selenium.server.FrameAddress

    public class FrameAddress

extends java.lang.Object

Method Summary
`boolean` | `equals(java.lang.Object obj)`
`java.lang.String` | `getLocalFrameAddress()`
`java.lang.String` | `getWindowName()`
`int` | `hashCode()`
`boolean` | `isDefault()`
`static FrameAddress` | `make(java.lang.String windowName, java.lang.String localFrameAddress)`
`void` | `setLocalFrameAddress(java.lang.String localFrameAddress)`
`void` | `setWindowName(java.lang.String windowName)`
`java.lang.String` | `toString()`

Methods inherited from class java.lang.Object
`clone, finalize, getClass, notify, notifyAll, wait, wait, wait`

Method Detail

### make

    public static FrameAddress make(java.lang.String windowName,
                                    java.lang.String localFrameAddress)

### toString

    public java.lang.String toString()

  Overrides:
    `toString` in class `java.lang.Object`

### getLocalFrameAddress

    public java.lang.String getLocalFrameAddress()

### getWindowName

    public java.lang.String getWindowName()

### isDefault

    public boolean isDefault()

### equals

    public boolean equals(java.lang.Object obj)

  Overrides:
    `equals` in class `java.lang.Object`

### hashCode

    public int hashCode()

  Overrides:
    `hashCode` in class `java.lang.Object`

### setLocalFrameAddress

    public void setLocalFrameAddress(java.lang.String localFrameAddress)

### setWindowName

    public void setWindowName(java.lang.String windowName)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.